@@ -17,21 +17,25 @@
 
 import inspect
 import os
+import oslo_messaging as messaging
+import osprofiler.notifier
+import osprofiler.web
 import random
 
+
 from oslo_concurrency import processutils
 from oslo_service import loopingcall
 from oslo_service import service
 from oslo_utils import importutils
-import osprofiler.notifier
-from osprofiler import profiler
-import osprofiler.web
+
 
 from venus.common.utils import LOG
 from venus.conf import CONF
 from venus import context
 from venus import exception
 from venus.i18n import _, _LI, _LW
+from venus.objects import base as objects_base
+from venus import rpc
 from venus import version
 from venus.wsgi import common as wsgi_common
 from venus.wsgi import eventlet_server as wsgi
@@ -71,11 +75,8 @@ class Service(service.Service):
         self.topic = topic
         self.manager_class_name = manager
         manager_class = importutils.import_class(self.manager_class_name)
-        manager_class = profiler.trace_cls("rpc")(manager_class)
 
-        self.manager = manager_class(host=self.host,
-                                     service_name=service_name,
-                                     *args, **kwargs)
+        self.manager = manager_class(*args, **kwargs)
         self.periodic_interval = periodic_interval
         self.periodic_fuzzy_delay = periodic_fuzzy_delay
         self.saved_args, self.saved_kwargs = args, kwargs
@@ -92,10 +93,14 @@ class Service(service.Service):
         self.manager.init_host()
         LOG.debug("Creating RPC server for service %s", self.topic)
 
-        # target = messaging.Target(topic=self.topic, server=self.host)
+        target = messaging.Target(topic=self.topic, server=self.host)
         endpoints = [self.manager]
         endpoints.extend(self.manager.additional_endpoints)
-        # serializer = objects_base.VenusObjectSerializer()
+        serializer = objects_base.VenusObjectSerializer()
+        self.rpcserver = rpc.get_server(target, endpoints, serializer)
+        self.rpcserver.start()
+
+        self.notifier = rpc.get_notifier("venus", self.host)
 
         self.manager.init_host_with_rpc()
 
@@ -133,8 +138,10 @@ class Service(service.Service):
             host = CONF.host
         if not binary:
             binary = os.path.basename(inspect.stack()[-1][1])
+        LOG.info(binary)
         if not topic:
             topic = binary
+        LOG.info(topic)
         if not manager:
             subtopic = topic.rpartition('venus-')[2]
             manager = CONF.get('%s_manager' % subtopic, None)
@@ -151,6 +158,7 @@ class Service(service.Service):
 
     def kill(self):
         """Destroy the service object in the datastore."""
+        LOG.info("Destroy the service object")
         self.stop()
 
     def stop(self):
@@ -163,7 +171,8 @@ class Service(service.Service):
         for x in self.timers:
             try:
                 x.stop()
-            except Exception:
+            except Exception as e:
+                LOG.error(e)
                 pass
         self.timers = []
         super(Service, self).stop()
@@ -172,7 +181,8 @@ class Service(service.Service):
         for x in self.timers:
             try:
                 x.wait()
-            except Exception:
+            except Exception as e:
+                LOG.error(e)
                 pass
         if self.rpcserver:
             self.rpcserver.wait()
@@ -183,7 +193,7 @@ class Service(service.Service):
         self.manager.periodic_tasks(ctxt, raise_on_error=raise_on_error)
 
 
-class WSGIService(service.ServiceBase):
+class WSGIService(service.Service):
     """Provides ability to launch API from a 'paste' configuration."""
 
     def __init__(self, name, loader=None):
@@ -210,6 +220,7 @@ class WSGIService(service.ServiceBase):
                     'workers': self.workers})
             raise exception.InvalidInput(msg)
         setup_profiler(name, self.host)
+        self.rpcserver = None
 
         self.server = wsgi.Server(name,
                                   self.app,
@@ -248,8 +259,15 @@ class WSGIService(service.ServiceBase):
         """
         if self.manager:
             self.manager.init_host()
+            self.topic = "xxxxxxx"
+            target = messaging.Target(topic=self.topic, server="10.49.38.57")
+            endpoints = [self.manager]
+            # endpoints.extend(self.manager.additional_endpoints)
+            serializer = objects_base.VenusObjectSerializer()
+            self.rpcserver = rpc.get_server(target, endpoints, serializer)
+            self.rpcserver.start()
+
         self.server.start()
-        self.port = self.server.port
 
     def stop(self):
         """Stop serving this API.
@@ -303,7 +321,8 @@ def wait():
         if ("_password" in flag or "_key" in flag or
                 (flag == "sql_connection" and
                     ("mysql:" in flag_get or "postgresql:" in flag_get))):
-            LOG.debug('%s : FLAG SET ', flag)
+            LOG.debug('%(flag)s : %(flag_get)s',
+                      {'flag': flag, 'flag_get': flag_get})
         else:
             LOG.debug('%(flag)s : %(flag_get)s',
                       {'flag': flag, 'flag_get': flag_get})
@@ -311,6 +330,9 @@ def wait():
         _launcher.wait()
     except KeyboardInterrupt:
         _launcher.stop()
+    except Exception as e:
+        LOG.error(e)
+        _launcher.stop()
 
 
 class Launcher(object):
